#[non_exhaustive]pub struct WeekInformation {
pub first_weekday: Weekday,
pub weekend: WeekdaySet,
}Expand description
Information about the first day of the week and the weekend.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.first_weekday: WeekdayThe first day of a week.
weekend: WeekdaySetThe set of weekend days
Implementations
Sourceimpl WeekInformation
impl WeekInformation
Sourcepub fn try_new(prefs: WeekPreferences) -> Result<Self, DataError>
pub fn try_new(prefs: WeekPreferences) -> Result<Self, DataError>
Creates a new WeekCalculator from compiled data.
✨ Enabled with the compiled_data Cargo feature.
Sourcepub fn try_new_unstable<P>(
provider: &P,
prefs: WeekPreferences,
) -> Result<Self, DataError>
pub fn try_new_unstable<P>( provider: &P, prefs: WeekPreferences, ) -> Result<Self, DataError>
A version of Self::try_new that uses custom data provided by a DataProvider.
⚠️ The bounds on provider may change over time, including in SemVer minor releases.
Sourcepub fn weekend(self) -> WeekdaySetIterator ⓘ
pub fn weekend(self) -> WeekdaySetIterator ⓘ
Weekdays that are part of the ‘weekend’, for calendar purposes. Days may not be contiguous, and order is based off the first weekday.