#[non_exhaustive]pub struct WeekPreferences {
pub locale_preferences: LocalePreferences,
pub first_weekday: Option<FirstDay>,
}Expand description
The preferences for the week information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.locale_preferences: LocalePreferencesLocale Preferences for the Preferences structure.
first_weekday: Option<FirstDay>The first day of the week
Implementations
Sourceimpl WeekPreferences
impl WeekPreferences
Sourcepub fn extend(&mut self, other: WeekPreferences)
pub fn extend(&mut self, other: WeekPreferences)
Extends the preferences with the values from another set of preferences.
Sourcepub fn from_locale_strict(loc: &Locale) -> Result<Self, Self>
pub fn from_locale_strict(loc: &Locale) -> Result<Self, Self>
Construct a WeekPreferences from a Locale
Returns Err if any of of the preference values are invalid.